"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const XRPMccConnection = {
    url: process.env.XRP_URL || "",
    username: process.env.XRP_USERNAME || "",
    password: process.env.XRP_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
    rateLimitOptions: {
        timeoutMs: 15000,
    },
};
describe("Block Xrp base test ", function () {
    let MccClient;
    let status;
    before(async function () {
        MccClient = new src_1.MCC.XRP(XRPMccConnection);
        status = await MccClient.getNodeStatus();
    });
    it("Should get status version ", async function () {
        const version = status.version.split("_");
        (0, chai_1.expect)(version[0]).to.be.oneOf(["1.9.1", "1.8.5", "1.9.4", "1.10.0", "1.10.1", "1.11.0"]);
    });
    it("Should get status state ", async function () {
        (0, chai_1.expect)(status.state).to.be.eq("full");
    });
    it("Should get status isHealthy ", async function () {
        (0, chai_1.expect)(status.isHealthy).to.eq(true);
    });
    it("Should get status isSynced ", async function () {
        (0, chai_1.expect)(status.isSynced).to.eq(true);
    });
});
describe("Xrp bottom block ", function () {
    let MccClient;
    before(async function () {
        MccClient = new src_1.MCC.XRP(XRPMccConnection);
    });
    it("Should get status version ", async function () {
        const bottom = await MccClient.getBottomBlockHeight();
        (0, chai_1.expect)(bottom).to.greaterThanOrEqual(32570);
    });
});
//# sourceMappingURL=status.test.js.map